@@ -1,12 +1,12 @@
 package CHI::Util;
-$CHI::Util::VERSION = '0.59';
+$CHI::Util::VERSION = '0.60';
 use Carp qw( croak longmess );
 use Module::Runtime qw(require_module);
 use Data::Dumper;
 use Data::UUID;
 use Fcntl qw( :DEFAULT );
 use File::Spec::Functions qw(catdir catfile);
-use JSON;
+use JSON::MaybeXS;
 use Time::Duration::Parse;
 use Try::Tiny;
 use strict;
@@ -32,11 +32,6 @@ our @EXPORT_OK = qw(
 my $Fetch_Flags = O_RDONLY | O_BINARY;
 my $Store_Flags = O_WRONLY | O_CREAT | O_BINARY;
 
-# Map null, true and false to real Perl values
-if ( JSON->VERSION < 2 ) {
-    $JSON::UnMapping = 1;
-}
-
 sub can_load {
 
     # Load $class_name if possible. Return 1 if successful, 0 if it could not be
@@ -182,21 +177,14 @@ sub parse_memory_size {
     }
 }
 
-# Maintain compatibility with both JSON 1 and 2. Borrowed from Data::Serializer::JSON.
-#
-use constant _OLD_JSON => JSON->VERSION < 2;
-my $json = _OLD_JSON ? JSON->new : JSON->new->utf8->canonical;
+my $json = JSON::MaybeXS->new( utf8 => 1, canonical => 1 );
 
 sub json_decode {
-    return _OLD_JSON
-      ? $json->jsonToObj( $_[0] )
-      : $json->decode( $_[0] );
+    $json->decode( $_[0] );
 }
 
 sub json_encode {
-    return _OLD_JSON
-      ? $json->objToJson( $_[0] )
-      : $json->encode( $_[0] );
+    $json->encode( $_[0] );
 }
 
 1;
